@@ -69,6 +69,9 @@ void print_pcap_thread_error(const char* func, int err)
     }
 }
 
+static pcap_thread_ext_frag_conf_t frag_conf_v4 = PCAP_THREAD_EXT_FRAG_CONF_T_INIT;
+static pcap_thread_ext_frag_conf_t frag_conf_v6 = PCAP_THREAD_EXT_FRAG_CONF_T_INIT;
+
 void open_pcaps(void)
 {
     mypcap_ptr mypcap;
@@ -114,33 +117,29 @@ void open_pcaps(void)
         }
 
         if (options.defrag_ipv4) {
-            pcap_thread_ext_frag_conf_t frag_conf = PCAP_THREAD_EXT_FRAG_CONF_T_INIT;
-
-            if (options.max_ipv4_fragments > 0 && (err = pcap_thread_ext_frag_conf_set_fragments(&frag_conf, options.max_ipv4_fragments)) != PCAP_THREAD_OK) {
+            if (options.max_ipv4_fragments > 0 && (err = pcap_thread_ext_frag_conf_set_fragments(&frag_conf_v4, options.max_ipv4_fragments)) != PCAP_THREAD_OK) {
                 print_pcap_thread_error("pcap_thread_ext_frag_conf_set_fragments()", err);
                 exit(1);
             }
-            if (options.max_ipv4_fragments_per_packet > 0 && (err = pcap_thread_ext_frag_conf_set_per_packet(&frag_conf, options.max_ipv4_fragments_per_packet)) != PCAP_THREAD_OK) {
+            if (options.max_ipv4_fragments_per_packet > 0 && (err = pcap_thread_ext_frag_conf_set_per_packet(&frag_conf_v4, options.max_ipv4_fragments_per_packet)) != PCAP_THREAD_OK) {
                 print_pcap_thread_error("pcap_thread_ext_frag_conf_set_per_packet()", err);
                 exit(1);
             }
-            if ((err = pcap_thread_set_callback_ipv4_frag(&pcap_thread, pcap_thread_ext_frag_layer_callback(&frag_conf))) != PCAP_THREAD_OK) {
+            if ((err = pcap_thread_set_callback_ipv4_frag(&pcap_thread, pcap_thread_ext_frag_layer_callback(&frag_conf_v4))) != PCAP_THREAD_OK) {
                 print_pcap_thread_error("pcap_thread_set_callback_ipv4_frag()", err);
                 exit(1);
             }
         }
         if (options.defrag_ipv6) {
-            pcap_thread_ext_frag_conf_t frag_conf = PCAP_THREAD_EXT_FRAG_CONF_T_INIT;
-
-            if (options.max_ipv6_fragments > 0 && (err = pcap_thread_ext_frag_conf_set_fragments(&frag_conf, options.max_ipv6_fragments)) != PCAP_THREAD_OK) {
+            if (options.max_ipv6_fragments > 0 && (err = pcap_thread_ext_frag_conf_set_fragments(&frag_conf_v6, options.max_ipv6_fragments)) != PCAP_THREAD_OK) {
                 print_pcap_thread_error("pcap_thread_ext_frag_conf_set_fragments()", err);
                 exit(1);
             }
-            if (options.max_ipv6_fragments_per_packet > 0 && (err = pcap_thread_ext_frag_conf_set_per_packet(&frag_conf, options.max_ipv6_fragments_per_packet)) != PCAP_THREAD_OK) {
+            if (options.max_ipv6_fragments_per_packet > 0 && (err = pcap_thread_ext_frag_conf_set_per_packet(&frag_conf_v6, options.max_ipv6_fragments_per_packet)) != PCAP_THREAD_OK) {
                 print_pcap_thread_error("pcap_thread_ext_frag_conf_set_per_packet()", err);
                 exit(1);
             }
-            if ((err = pcap_thread_set_callback_ipv6_frag(&pcap_thread, pcap_thread_ext_frag_layer_callback(&frag_conf))) != PCAP_THREAD_OK) {
+            if ((err = pcap_thread_set_callback_ipv6_frag(&pcap_thread, pcap_thread_ext_frag_layer_callback(&frag_conf_v6))) != PCAP_THREAD_OK) {
                 print_pcap_thread_error("pcap_thread_set_callback_ipv6_frag()", err);
                 exit(1);
             }
